# Copyright 2015-2020 Canonical Ltd.
#
# This file is part of the Telegraf Charm for Juju.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import re

from zaza import model

from .base import BaseTelegrafTest


class TestTelegrafCompute(BaseTelegrafTest):
    def test_01_metrics_available(self):
        # check metrics are available
        re_patterns = [
            r"^sockstat_",
            r"^sockstat6_",
            r"^softnet_stat",
            r"^buddyinfo_",
            r"^zoneinfo_",
            r"^processes_",
            r"^ovs_dump_flows_count.*br-data",
            r"^ovs_dpctl_TX_errors.*br-data",
        ]
        self.check_metrics(re_patterns)

    def test_04_plugin_errors(self):
        """Check there are no plugin errors in the telegraf log file."""
        content = model.file_contents(
            self.lead_unit_name, "/var/log/telegraf/telegraf.log"
        )
        # Sometimes, the logs show time out errors on Telegraf first start
        # because br-int isn't yet started.  To overcome this, just check
        # after the most recent plugin time out
        up_to_word = "command timed out"
        rx_to_last = r"^.*{}".format(re.escape(up_to_word))
        last_logs = re.sub(rx_to_last, "", content, flags=re.DOTALL).strip()
        error_pattern = "E!"
        self.assertFalse(re.findall(error_pattern, last_logs, flags=re.M))
